# `testpypippietruszka` - My simple project

* Opt 1
* Opt 2
* Opt 3

## install
```python
pip install testpypippietruszka
```

### Usage

```python
from testpypippietruszka.m_mod_pp import name as n
from testpypippietruszka.m_mod_pp import get_numpy_arr
>>> n("Name", "surename")
Name Surename
>>> get_numpy_arr([1, 2, 3, 4, 5])
[1 2 3 4 5]
```